/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

#include <libical/icaltime.h>
#include <libecal/e-cal-time-util.h>
#include <libjana-ecal/jana-ecal-time.h>
#include "jana-ecal-utils.h"

JanaTime *
jana_ecal_utils_time_now (const gchar *location)
{
	icaltimetype ical_time;
	const icaltimezone *zone;
	
	zone = (const icaltimezone *)icaltimezone_get_builtin_timezone (
		location);
	ical_time = icaltime_current_time_with_zone (zone);

	return jana_ecal_time_new_from_icaltime (&ical_time);
}

JanaTime *
jana_ecal_utils_time_today (const gchar *location)
{
	JanaTime *time;
	icaltimetype ical_time;
	const icaltimezone *zone;
	
	zone = (const icaltimezone *)icaltimezone_get_builtin_timezone (
		location);
	ical_time = icaltime_current_time_with_zone (zone);

	time = jana_ecal_time_new_from_icaltime (&ical_time);
	jana_time_set_isdate (time, TRUE);

	return time;
}

struct tm
jana_ecal_utils_time_to_tm (JanaEcalTime *time)
{
	icaltimetype *icaltime;
	
	g_object_get (G_OBJECT (time), "icaltime", &icaltime, NULL);
	return icaltimetype_to_tm (icaltime);
}

gchar *
jana_ecal_utils_strftime (JanaEcalTime *time, const gchar *format)
{
	gchar *string;
	gint size;
	struct tm brokentime = jana_ecal_utils_time_to_tm (time);
	
	if ((size = strftime (NULL, G_MAXINT, format, &brokentime))) {
		string = g_malloc (size + 1);
		strftime (string, size + 1, format, &brokentime);
		return string;
	} else return NULL;
}

