/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

#include "jana-component.h"

static void
jana_component_base_init (gpointer g_class)
{
	static gboolean initialized = FALSE;

	if (!initialized) {
		/* create interface signals here. */
		initialized = TRUE;
	}
}

GType
jana_component_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = {
			sizeof (JanaComponentInterface),
			jana_component_base_init,   /* base_init */
			NULL,

		};
		type = g_type_register_static (G_TYPE_INTERFACE,
			"JanaComponent", &info, 0);
	}
	return type;
}

JanaComponentType
jana_component_get_component_type (JanaComponent *self)
{
	return JANA_COMPONENT_GET_INTERFACE (self)->get_component_type (self);
}

gboolean
jana_component_is_fully_represented (JanaComponent *self)
{
	return JANA_COMPONENT_GET_INTERFACE (self)->is_fully_represented (self);
}

gchar *
jana_component_get_uid (JanaComponent *self)
{
	return JANA_COMPONENT_GET_INTERFACE (self)->get_uid (self);
}

gboolean
jana_component_supports_custom_props (JanaComponent *self)
{
	return JANA_COMPONENT_GET_INTERFACE (self)->
		supports_custom_props (self);
}

GList *
jana_component_get_custom_props_list (JanaComponent *self)
{
	return JANA_COMPONENT_GET_INTERFACE (self)->
		get_custom_props_list (self);
}

gchar *
jana_component_get_custom_prop (JanaComponent *self, const gchar *name)
{
	return JANA_COMPONENT_GET_INTERFACE (self)->
		get_custom_prop (self, name);
}

gboolean
jana_component_set_custom_prop (JanaComponent *self, const gchar *name,
				const gchar *value)
{
	return JANA_COMPONENT_GET_INTERFACE (self)->
		set_custom_prop (self, name, value);
}

void
jana_component_props_list_free (GList *props)
{
	while (props) {
		gchar **prop = (gchar **)props->data;
		g_free (prop[0]);
		g_free (prop[1]);
		g_free (prop);
		props = g_list_delete_link (props, props);
	}
}

