/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

#include <string.h>
#include "jana-event.h"

static void
jana_event_base_init (gpointer g_class)
{
	static gboolean initialized = FALSE;

	if (!initialized) {
		/* create interface signals here. */
		initialized = TRUE;
	}
}

GType
jana_event_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = {
			sizeof (JanaEventInterface),
			jana_event_base_init,   /* base_init */
			NULL,

		};
		type = g_type_register_static (G_TYPE_INTERFACE,
			"JanaEvent", &info, 0);
	}
	return type;
}

GType
jana_recurrence_get_type (void)
{
	static GType our_type = 0;

	if (!our_type)
		our_type = g_boxed_type_register_static ("JanaRecurrence",
			(GBoxedCopyFunc) jana_recurrence_copy,
			(GBoxedFreeFunc) jana_recurrence_free);

	return our_type;
}

JanaRecurrence *
jana_recurrence_new ()
{
	return g_slice_new0 (JanaRecurrence);
}

JanaRecurrence *
jana_recurrence_copy (JanaRecurrence *recurrence)
{
	JanaRecurrence *recurrence_copy;
	
	if (!recurrence) return NULL;
	
	recurrence_copy = jana_recurrence_new ();
	g_memmove (recurrence_copy, recurrence, sizeof (JanaRecurrence));
	recurrence_copy->end = jana_time_duplicate (recurrence->end);
	
	return recurrence_copy;
}

void
jana_recurrence_free (JanaRecurrence *recurrence)
{
	if (!recurrence) return;
	
	g_object_unref (recurrence->end);
	g_slice_free (JanaRecurrence, recurrence);
}

void
jana_exceptions_free (GList *exceptions)
{
	GList *e;
	for (e = exceptions; e; e = e->next)
		g_object_unref (G_OBJECT (e->data));
	g_list_free (exceptions);
}

gchar *
jana_event_get_summary (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_summary (self);
}

gchar *
jana_event_get_description (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_description (self);
}

gchar *
jana_event_get_location (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_location (self);
}

JanaTime *
jana_event_get_start (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_start (self);
}

JanaTime *
jana_event_get_end (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_end (self);
}

gchar **
jana_event_get_categories (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_categories (self);
}

gboolean
jana_event_supports_alarm (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->supports_alarm (self);
}

gboolean
jana_event_has_alarm (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->has_alarm (self);
}

JanaTime *
jana_event_get_alarm_time (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_alarm_time (self);
}

gboolean
jana_event_supports_recurrence (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->supports_recurrence (self);
}

gboolean
jana_event_has_recurrence (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->has_recurrence (self);
}

JanaRecurrence	*
jana_event_get_recurrence (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_recurrence (self);
}

gboolean
jana_event_supports_exceptions (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->supports_exceptions (self);
}

gboolean
jana_event_has_exceptions (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->has_exceptions (self);
}

GList *
jana_event_get_exceptions (JanaEvent *self)
{
	return JANA_EVENT_GET_INTERFACE (self)->get_exceptions (self);
}

void
jana_event_set_summary (JanaEvent *self, const gchar *summary)
{
	JANA_EVENT_GET_INTERFACE (self)->set_summary (self, summary);
}

void
jana_event_set_description (JanaEvent *self, const gchar *description)
{
	JANA_EVENT_GET_INTERFACE (self)->set_description (self, description);
}

void
jana_event_set_location (JanaEvent *self, const gchar *location)
{
	JANA_EVENT_GET_INTERFACE (self)->set_location (self, location);
}

void
jana_event_set_start (JanaEvent *self, JanaTime *start)
{
	JANA_EVENT_GET_INTERFACE (self)->set_start (self, start);
}

void
jana_event_set_end (JanaEvent *self, JanaTime *end)
{
	JANA_EVENT_GET_INTERFACE (self)->set_end (self, end);
}

void
jana_event_set_categories (JanaEvent *self, const gchar **categories)
{
	JANA_EVENT_GET_INTERFACE (self)->set_categories (self, categories);
}

void
jana_event_set_alarm (JanaEvent *self, JanaTime *time)
{
	JANA_EVENT_GET_INTERFACE (self)->set_alarm (self, time);
}

void
jana_event_set_recurrence (JanaEvent *self, const JanaRecurrence *recurrence)
{
	JANA_EVENT_GET_INTERFACE (self)->set_recurrence (self, recurrence);
}

void
jana_event_set_exceptions (JanaEvent *self, GList *exceptions)
{
	JANA_EVENT_GET_INTERFACE (self)->set_exceptions (self, exceptions);
}

