/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

#include "jana-store-view.h"

enum {
	ADDED,
	MODIFIED,
	REMOVED,
	LAST_SIGNAL
};

static void
jana_store_view_base_init (gpointer g_class)
{
	static gboolean initialized = FALSE;

	if (!initialized) {
		g_signal_new ("added",
			G_OBJECT_CLASS_TYPE (g_class),
			G_SIGNAL_RUN_LAST,
			G_STRUCT_OFFSET (JanaStoreViewInterface, added),
			NULL, NULL,
			g_cclosure_marshal_VOID__POINTER,
			G_TYPE_NONE, 1, G_TYPE_POINTER);

		g_signal_new ("modified",
			G_OBJECT_CLASS_TYPE (g_class),
			G_SIGNAL_RUN_LAST,
			G_STRUCT_OFFSET (JanaStoreViewInterface, modified),
			NULL, NULL,
			g_cclosure_marshal_VOID__POINTER,
			G_TYPE_NONE, 1, G_TYPE_POINTER);

		g_signal_new ("removed",
			G_OBJECT_CLASS_TYPE (g_class),
			G_SIGNAL_RUN_LAST,
			G_STRUCT_OFFSET (JanaStoreViewInterface, removed),
			NULL, NULL,
			g_cclosure_marshal_VOID__POINTER,
			G_TYPE_NONE, 1, G_TYPE_POINTER);

		initialized = TRUE;
	}
}

GType
jana_store_view_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = {
			sizeof (JanaStoreViewInterface),
			jana_store_view_base_init,   /* base_init */
			NULL,

		};
		type = g_type_register_static (G_TYPE_INTERFACE,
			"JanaStoreView", &info, 0);
	}
	return type;
}

void
jana_store_view_get_range (JanaStoreView *self,
			   JanaTime **start, JanaTime **end)
{
	JANA_STORE_VIEW_GET_INTERFACE (self)->get_range (self, start, end);
}

void
jana_store_view_set_range (JanaStoreView *self,
			   JanaTime *start, JanaTime *end)
{
	JANA_STORE_VIEW_GET_INTERFACE (self)->set_range (self, start, end);
}

void
jana_store_view_start (JanaStoreView *self)
{
	JANA_STORE_VIEW_GET_INTERFACE (self)->start (self);
}

JanaStore *
jana_store_view_get_store (JanaStoreView *self)
{
	return JANA_STORE_VIEW_GET_INTERFACE (self)->get_store (self);
}

