/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

#ifndef JANA_STORE_VIEW_H
#define JANA_STORE_VIEW_H

#include <glib-object.h>

#define JANA_TYPE_STORE_VIEW		(jana_store_view_get_type ())
#define JANA_STORE_VIEW(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj),\
					 JANA_TYPE_STORE_VIEW,\
					 JanaStoreView))
#define JANA_IS_STORE_VIEW(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj),\
					 JANA_TYPE_STORE_VIEW))
#define JANA_STORE_VIEW_GET_INTERFACE(inst)\
					(G_TYPE_INSTANCE_GET_INTERFACE ((inst),\
					 JANA_TYPE_STORE_VIEW,\
					 JanaStoreViewInterface))

typedef struct _JanaStoreView JanaStoreView; /* Dummy object */
typedef struct _JanaStoreViewInterface JanaStoreViewInterface;

#include <libjana/jana-time.h>
#include <libjana/jana-store.h>

struct _JanaStoreViewInterface {
	GTypeInterface parent;
	
	void	(*get_range)	(JanaStoreView *self, JanaTime **start,
					 JanaTime **end);
	
	void	(*set_range)	(JanaStoreView *self, JanaTime *start,
				 JanaTime *end);

	void	(*start)	(JanaStoreView *self);
	
	JanaStore *	(*get_store)	(JanaStoreView *self);
	
	/* Signals */
	void	(*added)	(JanaStoreView *self, GList *components);
	void	(*modified)	(JanaStoreView *self, GList *components);
	void	(*removed)	(JanaStoreView *self, GList *uids);
};

GType jana_store_view_get_type (void);

void	jana_store_view_get_range	(JanaStoreView *self, JanaTime **start,
					 JanaTime **end);

void	jana_store_view_set_range	(JanaStoreView *self, JanaTime *start,
					 JanaTime *end);

void	jana_store_view_start		(JanaStoreView *self);

JanaStore * jana_store_view_get_store	(JanaStoreView *self);

#endif /* JANA_STORE_VIEW_H */

