/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

#include "jana-time.h"

static void
jana_time_base_init (gpointer g_class)
{
	static gboolean initialized = FALSE;

	if (!initialized) {
		/* create interface signals here. */
		initialized = TRUE;
	}
}

GType
jana_time_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = {
			sizeof (JanaTimeInterface),
			jana_time_base_init,   /* base_init */
			NULL,

		};
		type = g_type_register_static (G_TYPE_INTERFACE,
			"JanaTime", &info, 0);
	}
	return type;
}

guint8
jana_time_get_seconds (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_seconds (self);
}

guint8
jana_time_get_minutes (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_minutes (self);
}

guint8
jana_time_get_hours (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_hours (self);
}

guint8
jana_time_get_day (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_day (self);
}

guint8
jana_time_get_month (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_month (self);
}

guint16
jana_time_get_year (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_year (self);
}

gboolean
jana_time_get_isdate (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_isdate (self);
}

gboolean
jana_time_get_daylight (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_daylight (self);
}

gchar *
jana_time_get_tzname (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_tzname (self);
}

glong
jana_time_get_offset (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->get_offset (self);
}

void
jana_time_set_seconds (JanaTime *self, gint seconds)
{
	JANA_TIME_GET_INTERFACE (self)->set_seconds (self, seconds);
}

void
jana_time_set_minutes (JanaTime *self, gint minutes)
{
	JANA_TIME_GET_INTERFACE (self)->set_minutes (self, minutes);
}
void
jana_time_set_hours (JanaTime *self, gint hours)
{
	JANA_TIME_GET_INTERFACE (self)->set_hours (self, hours);
}

void
jana_time_set_day (JanaTime *self, gint day)
{
	JANA_TIME_GET_INTERFACE (self)->set_day (self, day);
}

void
jana_time_set_month (JanaTime *self, gint month)
{
	JANA_TIME_GET_INTERFACE (self)->set_month (self, month);
}

void
jana_time_set_year (JanaTime *self, gint year)
{
	JANA_TIME_GET_INTERFACE (self)->set_year (self, year);
}

void
jana_time_set_isdate (JanaTime *self, gboolean isdate)
{
	JANA_TIME_GET_INTERFACE (self)->set_isdate (self, isdate);
}

void
jana_time_set_tzname (JanaTime *self, const gchar *tzname)
{
	JANA_TIME_GET_INTERFACE (self)->set_tzname (self, tzname);
}

void
jana_time_set_offset (JanaTime *self, glong offset)
{
	JANA_TIME_GET_INTERFACE (self)->set_offset (self, offset);
}

JanaTime *
jana_time_duplicate (JanaTime *self)
{
	return JANA_TIME_GET_INTERFACE (self)->duplicate (self);
}

GType
jana_duration_get_type (void)
{
	static GType our_type = 0;

	if (!our_type)
		our_type = g_boxed_type_register_static ("JanaDuration",
			(GBoxedCopyFunc) jana_duration_copy,
			(GBoxedFreeFunc) jana_duration_free);

	return our_type;
}

JanaDuration *
jana_duration_new (JanaTime *start, JanaTime *end)
{
	JanaDuration *duration = g_slice_new0 (JanaDuration);
	if (start) duration->start = jana_time_duplicate (start);
	if (end) duration->end = jana_time_duplicate (end);
	return duration;
}

JanaDuration *
jana_duration_copy (JanaDuration *duration)
{
	if (!duration) return NULL;
	
	return jana_duration_new (duration->start, duration->end);
}

void
jana_duration_set_start (JanaDuration *self, JanaTime *start)
{
	if (self->start) g_object_unref (self->start);
	self->start = start ? jana_time_duplicate (start) : NULL;
}

void
jana_duration_set_end (JanaDuration *self, JanaTime *end)
{
	if (self->end) g_object_unref (self->end);
	self->end = end ? jana_time_duplicate (end) : NULL;
}

gboolean
jana_duration_valid (JanaDuration *self)
{
	if (self && self->start && self->end &&
	    jana_utils_time_compare (self->start, self->end, FALSE) <= 0)
		return TRUE;
	else
		return FALSE;
}

void
jana_duration_free (JanaDuration *self)
{
	if (!self) return;
	
	g_object_unref (self->start);
	g_object_unref (self->end);
	g_slice_free (JanaDuration, self);
}

